"use strict";

module.exports = {
  /**
   * Behaves the same as setInterval except uses requestAnimationFrame() where possible for better performance
   * @param {function} fn The callback function
   * @param {int} delay The delay in milliseconds
   */
  setInterval: function(fn, delay) {
  	if (!window.requestAnimationFrame) {
  		return window.setInterval(fn, delay);
    }

  	let start = new Date().getTime();
  	let handle = new Object();

  	function loop() {
  		var current = new Date().getTime();
  		let delta = current - start;

  		if (delta >= delay) {
  			fn.call();
  			start = new Date().getTime();
  		}

  		handle.value = window.requestAnimationFrame(loop);
  	};

  	handle.value = window.requestAnimationFrame(loop);
  	return handle;
  },

  /**
   * Behaves the same as clearInterval except uses cancelAnimationFrame() where possible for better performance
   * @param {int|object} fn The callback function
   */
  clearInterval: function(handle) {
    window.cancelAnimationFrame ? window.cancelAnimationFrame(handle.value) :
    clearInterval(handle);
  }
};
