
/**
 * getDimensions - returns the width and height of a DOM element
 *
 * @return {Object}  An object that exposes width and height properties of the element
 */
function dimensions(el) {
  const rect = el.getBoundingClientRect();
  const width = rect.right - rect.left;
  const height = rect.bottom - rect.top;
  const bottom = rect.bottom;
  const top = rect.top;
  return {
    height,
    width,
    top,
    bottom
  }
}

function getPercentageOfElementInViewport(el) {
  const height = (window.innerHeight || document.body.clientHeight);
  const d = dimensions(el);
  if (d.bottom < 0 || d.bottom < height) {
    return 100;
  } else if (d.top > height) {
    return 0;
  } else if (d.top > 0) {
    return (100 / (d.height || 1)) * (height - d.top);
  } else {
    return (100 / (d.height || 1)) * (Math.abs(d.top) + height);
  }
}

module.exports = {
  dimensions,
  getPercentageOfElementInViewport
};
